@@ -1,5 +1,5 @@
 /* error.c --- Error handling functionality.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2009  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -38,7 +38,7 @@ struct gss_status_codes
   const char *text;
 };
 
-struct gss_status_codes gss_calling_errors[] = {
+static struct gss_status_codes gss_calling_errors[] = {
   {GSS_S_CALL_INACCESSIBLE_READ, "GSS_S_CALL_INACCESSIBLE_READ",
    N_("A required input parameter could not be read")},
   {GSS_S_CALL_INACCESSIBLE_WRITE, "GSS_S_CALL_INACCESSIBLE_WRITE",
@@ -47,7 +47,7 @@ struct gss_status_codes gss_calling_errors[] = {
    N_("A parameter was malformed")}
 };
 
-struct gss_status_codes gss_routine_errors[] = {
+static struct gss_status_codes gss_routine_errors[] = {
   {GSS_S_BAD_MECH, "GSS_S_BAD_MECH",
    N_("An unsupported mechanism was requested")},
   {GSS_S_BAD_NAME, "GSS_S_BAD_NAME",
@@ -87,7 +87,7 @@ struct gss_status_codes gss_routine_errors[] = {
    N_("The provided name was not a mechanism name")}
 };
 
-struct gss_status_codes gss_supplementary_errors[] = {
+static struct gss_status_codes gss_supplementary_errors[] = {
   {GSS_S_CONTINUE_NEEDED, "GSS_S_CONTINUE_NEEDED",
    N_("The gss_init_sec_context() or gss_accept_sec_context() function "
       "must be called again to complete its function")},
@@ -235,9 +235,15 @@ gss_display_status (OM_uint32 * minor_status,
 	case GSS_S_DUPLICATE_ELEMENT:
 	case GSS_S_NAME_NOT_MN:
 	  status_string->value =
-	    xstrdup (_(gss_routine_errors
-		       [(GSS_ROUTINE_ERROR (status_value) >>
-			 GSS_C_ROUTINE_ERROR_OFFSET) - 1].text));
+	    strdup (_(gss_routine_errors
+		      [(GSS_ROUTINE_ERROR (status_value) >>
+			GSS_C_ROUTINE_ERROR_OFFSET) - 1].text));
+	  if (!status_string->value)
+	    {
+	      if (minor_status)
+		*minor_status = ENOMEM;
+	      return GSS_S_FAILURE;
+	    }
 	  status_string->length = strlen (status_string->value);
 	  return GSS_S_COMPLETE;
 	  break;
@@ -264,9 +270,15 @@ gss_display_status (OM_uint32 * minor_status,
 	case GSS_S_CALL_INACCESSIBLE_WRITE:
 	case GSS_S_CALL_BAD_STRUCTURE:
 	  status_string->value =
-	    xstrdup (_(gss_calling_errors
-		       [(GSS_CALLING_ERROR (status_value) >>
-			 GSS_C_CALLING_ERROR_OFFSET) - 1].text));
+	    strdup (_(gss_calling_errors
+		      [(GSS_CALLING_ERROR (status_value) >>
+			GSS_C_CALLING_ERROR_OFFSET) - 1].text));
+	  if (!status_string->value)
+	    {
+	      if (minor_status)
+		*minor_status = ENOMEM;
+	      return GSS_S_FAILURE;
+	    }
 	  status_string->length = strlen (status_string->value);
 	  return GSS_S_COMPLETE;
 	  break;
@@ -282,7 +294,13 @@ gss_display_status (OM_uint32 * minor_status,
 	    GSS_SUPPLEMENTARY_INFO (status_value))
 	  {
 	    status_string->value =
-	      xstrdup (_(gss_supplementary_errors[i].text));
+	      strdup (_(gss_supplementary_errors[i].text));
+	    if (!status_string->value)
+	      {
+		if (minor_status)
+		  *minor_status = ENOMEM;
+		return GSS_S_FAILURE;
+	      }
 	    status_string->length = strlen (status_string->value);
 	    *message_context |= gss_supplementary_errors[i].err;
 	    if ((status_value & ~*message_context) == 0)
@@ -295,7 +313,13 @@ gss_display_status (OM_uint32 * minor_status,
 
       if (message_context)
 	*message_context = 0;
-      status_string->value = xstrdup (_("No error"));
+      status_string->value = strdup (_("No error"));
+      if (!status_string->value)
+	{
+	  if (minor_status)
+	    *minor_status = ENOMEM;
+	  return GSS_S_FAILURE;
+	}
       status_string->length = strlen (status_string->value);
       break;
 
