@@ -33,14 +33,12 @@
 #include <ctype.h>
 #include <string.h>
 #include <time.h>
+#include <errno.h>
 
 /* Get specification. */
 #include <gss/api.h>
 #include <gss/ext.h>
 
-/* Get xmalloc etc. */
-#include "xalloc.h"
-
 typedef struct gss_name_struct
 {
   size_t length;
