@@ -1,5 +1,5 @@
 /* k5internal.h --- Internal header file for Kerberos 5 GSS.
- * Copyright (C) 2003, 2004, 2005, 2006, 2007  Simon Josefsson
+ * Copyright (C) 2003, 2004, 2005, 2006, 2007, 2009  Simon Josefsson
  *
  * This file is part of the Generic Security Service (GSS).
  *
@@ -21,8 +21,8 @@
  */
 
 #include "internal.h"
-#include "krb5.h"
 #include "protos.h"
+#include <gss/krb5.h>
 
 #include <shishi.h>
 
